@@ -22,11 +22,12 @@ class Doge(object):
     # wow pls extend this if you see it
     known_processes = (
         # wow shells and terminals and etc
-        'zsh', 'urxvt', 'tmux', 'fish', 'ssh', 'mutt', 'screen', 'mosh-client',
+        'urxvt', 'tmux', 'fish', 'ssh', 'mutt', 'screen', 'mosh-client',
+        'Terminal',
 
         # pretty browsers
         'chromium', 'luakit', 'uzbl-core', 'firefox', 'jumanji', 'chrome',
-        'thunderbird',
+        'thunderbird', 'Safari', 'Google Chrome',
 
         # many wms (borrow from djmelik/archey)
         'awesome', 'beryl', 'blackbox', 'bspwm', 'compiz', 'dwm',
@@ -38,13 +39,18 @@ class Doge(object):
         # such services and daemons
         'mpd', 'nginx', 'dzen2', 'systemd', 'lighttpd', 'prosody',
         'mongod', 'postgres', 'mysqld', 'redis-server', 'php-fpm',
-        'sendmail', 'irssi', 'screen', 'neo4j', 'httpd',
-        
+        'sendmail', 'irssi', 'screen', 'neo4j', 'httpd', 'Flux', 'Dropbox',
+        'VirtualBox', 'VirtualBoxVM', 'tmux', 'xflux', 'weechat', 'xen',
+        'apache', 'sshd',
+
         # programming languages
-        'ruby', 'python', 'java', 'php',
-        
+        'ruby', 'python', 'java', 'php', 'node', 'erlang',
+
         # so editors
-        'emacs', 'vim', 'nano', 'gedit', 'sublime_text',
+        'emacs', 'vim', 'nano', 'gedit', 'sublime_text', 'subl', 'other',
+
+        # very talk
+        'HipChat', 'Mail',
 
         # shells
         'sh', 'bash', 'zsh'
@@ -85,7 +91,7 @@ class Doge(object):
 
     def apply_text(self):
         linelen = len(self.lines)
-        affected = random.sample(range(linelen), int(linelen / 4))
+        affected = random.sample(range(linelen), int(linelen / 3.5))
 
         real_targets = self.real_data
         # wow only sample if more than need
@@ -99,6 +105,8 @@ class Doge(object):
             word = None
             if x in real_targets and random.choice(range(2)) == 0:
                 word = self.real_data.pop()
+            elif x in affected[-2:]:
+                word = 'wow'
 
             msg = DogeMessage(self.tty, clean_len(line), word=word)
             self.lines[x] = '{0}{1}'.format(line, msg)
@@ -170,19 +178,19 @@ class Doge(object):
 class DogeMessage(object):
     prefixes = [
         'wow', 'such', 'very', 'so much', 'many', 'lol', 'beautiful',
-        'all the', 'the', 'most', 'very much', 'pretty', 'so'
+        'all the', 'the', 'most', 'very much', 'pretty', 'so', 'lots'
     ]
 
     words = [
         'computer', 'hax0r', 'code', 'data', 'internet', 'server',
         'hacker', 'terminal', 'doge', 'shibe', 'program', 'free software',
         'web scale', 'monads', 'git', 'daemon', 'cloud computing', 'real-time',
-        'cloud', 'loop', 'big data', 'synergy', 'agile', 'viral', 'ROI',
-        'innovative'
+        'cloud', 'loop', 'big data', 'synergy', 'agile', 'viral', 'roi',
+        'innovative', 'cloud scale', 'pretty', 'uptime'
     ]
 
     suffixes = [
-        'wow', 'lol', 'hax', 'plz'
+        'wow', 'lol', 'hax', 'plz', 'lvl=100'
     ]
 
     def __init__(self, tty, occupied, word=None):
@@ -217,13 +225,17 @@ class DogeMessage(object):
         self.message = '{0}{1}'.format(space, self.message)
 
     def generate(self):
-        if not self.word:
-            self.word = random.choice(self.words)
+        if self.word == 'wow':
+            # wow standalone wow
+            msg = self.word
+        else:
+            if not self.word:
+                self.word = random.choice(self.words)
 
-        msg = '{0} {1}'.format(random.choice(self.prefixes), self.word)
+            msg = '{0} {1}'.format(random.choice(self.prefixes), self.word)
 
-        if random.choice(range(15)) == 0:
-            msg += ' {0}'.format(random.choice(self.suffixes))
+            if random.choice(range(15)) == 0:
+                msg += ' {0}'.format(random.choice(self.suffixes))
 
         self.orig_message = msg
         self.message = msg
